from setuptools import setup

setup(name='fem_probability',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['fem_probability'],
      author = 'Femi Tofade',
      author_email = 'tolatof@gmail.com',
      zip_safe=False)
